@@ -18,10 +18,8 @@ import concurrent.futures
 import hashlib
 import json
 import os
-import six
 import types  # noqa
-
-from six.moves import urllib_parse
+import urllib.parse
 
 import keystoneauth1.exceptions
 
@@ -242,7 +240,7 @@ class ObjectStoreCloudMixin(_normalize.Normalizer):
         # The endpoint in the catalog has version and project-id in it
         # To get capabilities, we have to disassemble and reassemble the URL
         # This logic is taken from swiftclient
-        endpoint = urllib_parse.urlparse(self.object_store.get_endpoint())
+        endpoint = urllib.parse.urlparse(self.object_store.get_endpoint())
         url = "{scheme}://{netloc}/info".format(
             scheme=endpoint.scheme, netloc=endpoint.netloc)
 
@@ -257,9 +255,6 @@ class ObjectStoreCloudMixin(_normalize.Normalizer):
             caps = self.get_object_capabilities()
         except exc.OpenStackCloudHTTPError as e:
             if e.response.status_code in (404, 412):
-                # Clear the exception so that it doesn't linger
-                # and get reported as an Inner Exception later
-                _utils._exc_clear()
                 server_max_file_size = DEFAULT_MAX_FILE_SIZE
                 self.log.info(
                     "Swift capabilities not supported. "
@@ -753,11 +748,11 @@ class ObjectStoreCloudMixin(_normalize.Normalizer):
         return self._object_store_client.get(endpoint, stream=stream)
 
     def _get_object_endpoint(self, container, obj=None, query_string=None):
-        endpoint = urllib_parse.quote(container)
+        endpoint = urllib.parse.quote(container)
         if obj:
             endpoint = '{endpoint}/{object}'.format(
                 endpoint=endpoint,
-                object=urllib_parse.quote(obj)
+                object=urllib.parse.quote(obj)
             )
         if query_string:
             endpoint = '{endpoint}?{query_string}'.format(
@@ -820,14 +815,14 @@ class ObjectStoreCloudMixin(_normalize.Normalizer):
                 response_headers = {
                     k.lower(): v for k, v in response.headers.items()}
                 if outfile:
-                    if isinstance(outfile, six.string_types):
+                    if isinstance(outfile, str):
                         outfile_handle = open(outfile, 'wb')
                     else:
                         outfile_handle = outfile
                     for chunk in response.iter_content(
                             resp_chunk_size, decode_unicode=False):
                         outfile_handle.write(chunk)
-                    if isinstance(outfile, six.string_types):
+                    if isinstance(outfile, str):
                         outfile_handle.close()
                     else:
                         outfile_handle.flush()
