@@ -13,7 +13,9 @@
 # under the License.
 
 import copy
+import os.path
 import warnings
+import urllib
 
 from keystoneauth1 import discover
 import keystoneauth1.exceptions.catalog
@@ -21,7 +23,6 @@ from keystoneauth1.loading import adapter as ks_load_adap
 from keystoneauth1 import session as ks_session
 import os_service_types
 import requestsexceptions
-from six.moves import urllib
 try:
     import statsd
 except ImportError:
@@ -201,7 +202,7 @@ def from_conf(conf, session=None, service_types=None, **kwargs):
         session=session, config=config_dict, **kwargs)
 
 
-class CloudRegion(object):
+class CloudRegion:
     # TODO(efried): Doc the rest of the kwargs
     """The configuration for a Region of an OpenStack Cloud.
 
@@ -321,6 +322,10 @@ class CloudRegion(object):
         else:
             return 'unknown'
 
+    def set_service_value(self, key, service_type, value):
+        key = _make_key(key, service_type)
+        self.config[key] = value
+
     def set_session_constructor(self, session_constructor):
         """Sets the Session constructor."""
         self._session_constructor = session_constructor
@@ -334,7 +339,7 @@ class CloudRegion(object):
         if insecure:
             verify = False
         if verify and cacert:
-            verify = cacert
+            verify = os.path.expanduser(cacert)
         else:
             if cacert:
                 warnings.warn(
@@ -345,8 +350,9 @@ class CloudRegion(object):
 
         cert = self.config.get('cert')
         if cert:
+            cert = os.path.expanduser(cert)
             if self.config.get('key'):
-                cert = (cert, self.config.get('key'))
+                cert = (cert, os.path.expanduser(self.config.get('key')))
         return (verify, cert)
 
     def get_services(self):
@@ -359,6 +365,21 @@ class CloudRegion(object):
                 services.append("_".join(key.split('_')[:-2]))
         return list(set(services))
 
+    def get_enabled_services(self):
+        services = set()
+
+        all_services = [k['service_type'] for k in
+                        self._service_type_manager.services]
+        all_services.extend(k[4:] for k in
+                            self.config.keys() if k.startswith('has_'))
+
+        for srv in all_services:
+            ep = self.get_endpoint_from_catalog(srv)
+            if ep:
+                services.add(srv.replace('-', '_'))
+
+        return services
+
     def get_auth_args(self):
         return self.config.get('auth', {})
 
@@ -471,6 +492,18 @@ class CloudRegion(object):
             # Specifically, looking up a list of projects/domains/system to
             # scope to.
             value = auth.get('auth_url')
+        # Because of course. Seriously.
+        # We have to override the Rackspace block-storage endpoint because
+        # only v1 is in the catalog but the service actually does support
+        # v2. But the endpoint needs the project_id.
+        service_type = self._service_type_manager.get_service_type(
+            service_type)
+        if (
+            value
+            and self.config.get('profile') == 'rackspace'
+            and service_type == 'block-storage'
+        ):
+            value = value + auth.get('project_id')
         return value
 
     def get_endpoint_from_catalog(
@@ -645,7 +678,7 @@ class CloudRegion(object):
             self.get_interface(service_type), {})
         return interface_versions.get(service_type, [])
 
-    def _get_hardcoded_endpoint(self, service_type, constructor):
+    def _get_endpoint_from_catalog(self, service_type, constructor):
         adapter = constructor(
             session=self.get_session(),
             service_type=self.get_service_type(service_type),
@@ -653,7 +686,11 @@ class CloudRegion(object):
             interface=self.get_interface(service_type),
             region_name=self.get_region_name(service_type),
         )
-        endpoint = adapter.get_endpoint()
+        return adapter.get_endpoint()
+
+    def _get_hardcoded_endpoint(self, service_type, constructor):
+        endpoint = self._get_endpoint_from_catalog(
+            service_type, constructor)
         if not endpoint.rstrip().rsplit('/')[-1] == 'v2.0':
             if not endpoint.endswith('/'):
                 endpoint += '/'
