@@ -32,7 +32,7 @@ class Listener(resource.Resource, resource.TagMixin):
         'sni_container_refs', 'insert_headers', 'load_balancer_id',
         'timeout_client_data', 'timeout_member_connect',
         'timeout_member_data', 'timeout_tcp_inspect', 'allowed_cidrs',
-        'tls_ciphers',
+        'tls_ciphers', 'tls_versions', 'alpn_protocols',
         is_admin_state_up='admin_state_up',
         **resource.TagMixin._tag_query_parameters
     )
@@ -40,6 +40,8 @@ class Listener(resource.Resource, resource.TagMixin):
     # Properties
     #: List of IPv4 or IPv6 CIDRs.
     allowed_cidrs = resource.Body('allowed_cidrs', type=list)
+    #: List of ALPN protocols.
+    alpn_protocols = resource.Body('alpn_protocols', type=list)
     #: The maximum number of connections permitted for this load balancer.
     #: Default is infinite.
     connection_limit = resource.Body('connection_limit')
@@ -94,6 +96,8 @@ class Listener(resource.Resource, resource.TagMixin):
     timeout_tcp_inspect = resource.Body('timeout_tcp_inspect', type=int)
     #: Stores a cipher string in OpenSSL format.
     tls_ciphers = resource.Body('tls_ciphers')
+    #: A lsit of TLS protocols to be used by the listener
+    tls_versions = resource.Body('tls_versions', type=list)
 
 
 class ListenerStats(resource.Resource):
