@@ -29,7 +29,7 @@ class Pool(resource.Resource, resource.TagMixin):
         'health_monitor_id', 'lb_algorithm', 'listener_id', 'loadbalancer_id',
         'description', 'name', 'project_id', 'protocol',
         'created_at', 'updated_at', 'provisioning_status', 'operating_status',
-        'tls_ciphers',
+        'tls_enabled', 'tls_ciphers', 'tls_versions',
         is_admin_state_up='admin_state_up',
         **resource.TagMixin._tag_query_parameters
     )
@@ -69,5 +69,9 @@ class Pool(resource.Resource, resource.TagMixin):
     tls_ciphers = resource.Body('tls_ciphers')
     #: A JSON object specifying the session persistence for the pool.
     session_persistence = resource.Body('session_persistence', type=dict)
+    #: A list of TLS protocol versions to be used in by the pool
+    tls_versions = resource.Body('tls_versions', type=list)
     #: Timestamp when the pool was updated
     updated_at = resource.Body('updated_at')
+    #: Use TLS for connections to backend member servers *Type: bool*
+    tls_enabled = resource.Body('tls_enabled', type=bool)
