@@ -10,27 +10,28 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.orchestration import orchestration_service
-from openstack import resource2 as resource
+from openstack import resource
 
 
 class StackTemplate(resource.Resource):
 
-    service = orchestration_service.OrchestrationService()
     base_path = "/stacks/%(stack_name)s/%(stack_id)s/template"
 
     # capabilities
     allow_create = False
     allow_list = False
-    allow_get = True
+    allow_fetch = True
     allow_delete = False
-    allow_update = False
+    allow_commit = False
 
     # Properties
     #: Name of the stack where the template is referenced.
-    stack_name = resource.URI('stack_name')
+    name = resource.URI('stack_name')
+    # Backwards compat. _stack_name will never match, but the alias will
+    # point it to the value pulled for name.
+    stack_name = resource.URI('_stack_name', alias='name')
     #: ID of the stack where the template is referenced.
-    stack_id = resource.URI('stack_id')
+    stack_id = resource.URI('stack_id', alternate_id=True)
     #: The description specified in the template
     description = resource.Body('Description')
     #: The version of the orchestration HOT template.
@@ -44,12 +45,5 @@ class StackTemplate(resource.Resource):
     resources = resource.Body('resources', type=dict)
     # List parameters grouped.
     parameter_groups = resource.Body('parameter_groups', type=list)
-    # Restrict conditions.
+    # Restrict conditions which supported since '2016-10-14'.
     conditions = resource.Body('conditions', type=dict)
-
-    def to_dict(self):
-        mapping = super(StackTemplate, self).to_dict()
-        mapping.pop('location')
-        mapping.pop('id')
-        mapping.pop('name')
-        return mapping
