@@ -10,13 +10,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from unittest import mock
+
 from keystoneauth1 import adapter
-import mock
 
 from openstack.baremetal.v1 import _common
 from openstack.baremetal.v1 import node
 from openstack import exceptions
 from openstack import resource
+from openstack import utils
 from openstack.tests.unit import base
 
 # NOTE: Sample data from api-ref doc
@@ -229,6 +231,11 @@ class TestNodeWaitForProvisionState(base.TestCase):
                           abort_on_failed_state=False)
 
 
+def _fake_assert(self, session, action, expected, error_message=None):
+    return expected
+
+
+@mock.patch.object(node.Node, '_assert_microversion_for', _fake_assert)
 @mock.patch.object(node.Node, 'fetch', lambda self, session: self)
 @mock.patch.object(exceptions, 'raise_from_response', mock.Mock())
 class TestNodeSetProvisionState(base.TestCase):
@@ -558,6 +565,7 @@ class TestNodeWaitForReservation(base.TestCase):
         mock_fetch.assert_called_with(self.node, self.session)
 
 
+@mock.patch.object(node.Node, '_assert_microversion_for', _fake_assert)
 @mock.patch.object(exceptions, 'raise_from_response', mock.Mock())
 class TestNodeSetPowerState(base.TestCase):
 
@@ -724,6 +732,7 @@ class TestNodeSetBootDevice(base.TestCase):
             retriable_status_codes=_common.RETRIABLE_STATUS_CODES)
 
 
+@mock.patch.object(utils, 'pick_microversion', lambda session, v: v)
 @mock.patch.object(node.Node, 'fetch', lambda self, session: self)
 @mock.patch.object(exceptions, 'raise_from_response', mock.Mock())
 class TestNodeTraits(base.TestCase):
@@ -769,6 +778,7 @@ class TestNodeTraits(base.TestCase):
             retriable_status_codes=_common.RETRIABLE_STATUS_CODES)
 
 
+@mock.patch.object(node.Node, '_assert_microversion_for', _fake_assert)
 @mock.patch.object(resource.Resource, 'patch', autospec=True)
 class TestNodePatch(base.TestCase):
 
@@ -783,7 +793,7 @@ class TestNodePatch(base.TestCase):
         patch = {'path': 'test'}
         self.node.patch(self.session, patch=patch)
         mock_patch.assert_called_once()
-        kwargs = mock_patch.call_args.kwargs
+        kwargs = mock_patch.call_args[1]
         self.assertEqual(kwargs['patch'], {'path': 'test'})
 
     @mock.patch.object(resource.Resource, '_prepare_request', autospec=True)
@@ -794,12 +804,39 @@ class TestNodePatch(base.TestCase):
         self.node.patch(self.session, patch=patch, retry_on_conflict=True,
                         reset_interfaces=True)
         mock_prepreq.assert_called_once()
-        prepreq_kwargs = mock_prepreq.call_args.kwargs
+        prepreq_kwargs = mock_prepreq.call_args[1]
         self.assertEqual(prepreq_kwargs['params'],
                          [('reset_interfaces', True)])
         mock__commit.assert_called_once()
-        commit_args = mock__commit.call_args.args
-        commit_kwargs = mock__commit.call_args.kwargs
+        commit_args = mock__commit.call_args[0]
+        commit_kwargs = mock__commit.call_args[1]
         self.assertIn('1.45', commit_args)
         self.assertEqual(commit_kwargs['retry_on_conflict'], True)
         mock_patch.assert_not_called()
+
+
+@mock.patch('time.sleep', lambda _t: None)
+@mock.patch.object(node.Node, 'fetch', autospec=True)
+class TestNodeWaitForPowerState(base.TestCase):
+    def setUp(self):
+        super(TestNodeWaitForPowerState, self).setUp()
+        self.node = node.Node(**FAKE)
+        self.session = mock.Mock()
+
+    def test_success(self, mock_fetch):
+        self.node.power_state = 'power on'
+
+        def _get_side_effect(_self, session):
+            self.node.power_state = 'power off'
+            self.assertIs(session, self.session)
+
+        mock_fetch.side_effect = _get_side_effect
+
+        node = self.node.wait_for_power_state(self.session, 'power off')
+        self.assertIs(node, self.node)
+
+    def test_timeout(self, mock_fetch):
+        self.node.power_state = 'power on'
+        self.assertRaises(exceptions.ResourceTimeout,
+                          self.node.wait_for_power_state,
+                          self.session, 'power off', timeout=0.001)
