@@ -14,19 +14,23 @@
 # under the License.
 
 import collections
+import os
+import tempfile
 import time
 import uuid
+import urllib
 
 import fixtures
-import os
+from keystoneauth1 import loading as ks_loading
 import openstack.config as occ
+from oslo_config import cfg
 from requests import structures
 from requests_mock.contrib import fixture as rm_fixture
-from six.moves import urllib
-import tempfile
 
 import openstack.cloud
 import openstack.connection
+from openstack.tests import fakes
+from openstack.fixture import connection as os_fixture
 from openstack.tests import base
 
 
@@ -99,6 +103,8 @@ class TestCase(base.TestCase):
                                              'time.sleep',
                                              _nosleep))
         self.fixtures_directory = 'openstack/tests/unit/fixtures'
+        self.os_fixture = self.useFixture(
+            os_fixture.ConnectionFixture(project_id=fakes.PROJECT_ID))
 
         # Isolate openstack.config from test environment
         config = tempfile.NamedTemporaryFile(delete=False)
@@ -118,6 +124,23 @@ class TestCase(base.TestCase):
             vendor_files=[vendor.name],
             secure_files=['non-existant'])
 
+        self.oslo_config_dict = {
+            # All defaults for nova
+            'nova': {},
+            # monasca-api not in the service catalog
+            'monasca-api': {},
+            # Overrides for heat
+            'heat': {
+                'region_name': 'SpecialRegion',
+                'interface': 'internal',
+                'endpoint_override': 'https://example.org:8888/heat/v2'
+            },
+            # test a service with dashes
+            'ironic_inspector': {
+                'endpoint_override': 'https://example.org:5050',
+            },
+        }
+
         # FIXME(notmorgan): Convert the uri_registry, discovery.json, and
         # use of keystone_v3/v2 to a proper fixtures.Fixture. For now this
         # is acceptable, but eventually this should become it's own fixture
@@ -139,6 +162,16 @@ class TestCase(base.TestCase):
         self.use_keystone_v3()
         self.__register_uris_called = False
 
+    def _load_ks_cfg_opts(self):
+        conf = cfg.ConfigOpts()
+        for group, opts in self.oslo_config_dict.items():
+            conf.register_group(cfg.OptGroup(group))
+            if opts is not None:
+                ks_loading.register_adapter_conf_options(conf, group)
+                for name, val in opts.items():
+                    conf.set_override(name, val, group=group)
+        return conf
+
     # TODO(shade) Update this to handle service type aliases
     def get_mock_url(self, service_type, interface='public', resource=None,
                      append=None, base_url_append=None,
@@ -154,10 +187,13 @@ class TestCase(base.TestCase):
             to_join.append(base_url_append)
         if resource:
             to_join.append(resource)
-        to_join.extend(append or [])
+        if append:
+            to_join.extend([urllib.parse.quote(i) for i in append])
         if qs_elements is not None:
             qs = '?%s' % '&'.join(qs_elements)
-        return '%(uri)s%(qs)s' % {'uri': '/'.join(to_join), 'qs': qs}
+        return '%(uri)s%(qs)s' % {
+            'uri': '/'.join(to_join),
+            'qs': qs}
 
     def mock_for_keystone_projects(self, project=None, v3=True,
                                    list_get=False, id_get=False,
@@ -391,24 +427,59 @@ class TestCase(base.TestCase):
         self.calls = []
         self._uri_registry.clear()
 
-    def use_keystone_v3(self, catalog='catalog-v3.json'):
+    def get_keystone_v3_token(
+            self,
+            project_name='admin',
+    ):
+        return dict(
+            method='POST',
+            uri='https://identity.example.com/v3/auth/tokens',
+            headers={
+                'X-Subject-Token': self.getUniqueString('KeystoneToken')
+            },
+            json=self.os_fixture.v3_token,
+            validate=dict(json={
+                'auth': {
+                    'identity': {
+                        'methods': ['password'],
+                        'password': {
+                            'user': {
+                                'domain': {
+                                    'name': 'default',
+                                },
+                                'name': 'admin',
+                                'password': 'password'
+                            }
+                        }
+                    },
+                    'scope': {
+                        'project': {
+                            'domain': {
+                                'name': 'default'
+                            },
+                            'name': project_name
+                        }
+                    }
+                }
+            }),
+        )
+
+    def get_keystone_discovery(self):
+        with open(self.discovery_json, 'r') as discovery_file:
+            return dict(
+                method='GET',
+                uri='https://identity.example.com/',
+                text=discovery_file.read(),
+            )
+
+    def use_keystone_v3(self):
         self.adapter = self.useFixture(rm_fixture.Fixture())
         self.calls = []
         self._uri_registry.clear()
-        with open(self.discovery_json, 'r') as discovery_file, \
-            open(os.path.join(
-                self.fixtures_directory, catalog), 'r') as tokens_file:
-            self.__do_register_uris([
-                dict(method='GET', uri='https://identity.example.com/',
-                     text=discovery_file.read()),
-                dict(method='POST',
-                     uri='https://identity.example.com/v3/auth/tokens',
-                     headers={
-                         'X-Subject-Token':
-                         self.getUniqueString('KeystoneToken')},
-                     text=tokens_file.read()
-                     ),
-            ])
+        self.__do_register_uris([
+            self.get_keystone_discovery(),
+            self.get_keystone_v3_token(),
+        ])
         self._make_test_cloud(identity_api_version='3')
 
     def use_keystone_v2(self):
@@ -416,18 +487,13 @@ class TestCase(base.TestCase):
         self.calls = []
         self._uri_registry.clear()
 
-        with open(self.discovery_json, 'r') as discovery_file, \
-            open(os.path.join(
-                self.fixtures_directory,
-                'catalog-v2.json'), 'r') as tokens_file:
-            self.__do_register_uris([
-                dict(method='GET', uri='https://identity.example.com/',
-                     text=discovery_file.read()),
-                dict(method='POST',
-                     uri='https://identity.example.com/v2.0/tokens',
-                     text=tokens_file.read()
-                     ),
-            ])
+        self.__do_register_uris([
+            self.get_keystone_discovery(),
+            dict(method='POST',
+                 uri='https://identity.example.com/v2.0/tokens',
+                 json=self.os_fixture.v2_token,
+                 ),
+        ])
 
         self._make_test_cloud(cloud_name='_test_cloud_v2_',
                               identity_api_version='2.0')
@@ -438,12 +504,11 @@ class TestCase(base.TestCase):
             cloud=test_cloud, validate=True, **kwargs)
         self.cloud = openstack.connection.Connection(
             config=self.cloud_config, strict=self.strict_cloud)
-        self.addCleanup(self.cloud.task_manager.stop)
 
     def get_cinder_discovery_mock_dict(
             self,
             block_storage_version_json='block-storage-version.json',
-            block_storage_discovery_url='https://volume.example.com/'):
+            block_storage_discovery_url='https://block-storage.example.com/'):
         discovery_fixture = os.path.join(
             self.fixtures_directory, block_storage_version_json)
         return dict(method='GET', uri=block_storage_discovery_url,
@@ -470,9 +535,10 @@ class TestCase(base.TestCase):
             uri=compute_discovery_url,
             text=open(discovery_fixture, 'r').read())
 
-    def get_placement_discovery_mock_dict(self):
+    def get_placement_discovery_mock_dict(
+            self, discovery_fixture='placement.json'):
         discovery_fixture = os.path.join(
-            self.fixtures_directory, "placement.json")
+            self.fixtures_directory, discovery_fixture)
         return dict(method='GET', uri="https://placement.example.com/",
                     text=open(discovery_fixture, 'r').read())
 
@@ -485,7 +551,7 @@ class TestCase(base.TestCase):
     def get_ironic_discovery_mock_dict(self):
         discovery_fixture = os.path.join(
             self.fixtures_directory, "baremetal.json")
-        return dict(method='GET', uri="https://bare-metal.example.com/",
+        return dict(method='GET', uri="https://baremetal.example.com/",
                     text=open(discovery_fixture, 'r').read())
 
     def get_senlin_discovery_mock_dict(self):
@@ -502,6 +568,12 @@ class TestCase(base.TestCase):
                 compute_version_json, compute_discovery_url),
         ])
 
+    def get_cyborg_discovery_mock_dict(self):
+        discovery_fixture = os.path.join(
+            self.fixtures_directory, "accelerator.json")
+        return dict(method='GET', uri="https://accelerator.example.com/",
+                    text=open(discovery_fixture, 'r').read())
+
     def use_glance(
             self, image_version_json='image-version.json',
             image_discovery_url='https://image.example.com/'):
@@ -514,9 +586,13 @@ class TestCase(base.TestCase):
             self.get_glance_discovery_mock_dict(
                 image_version_json, image_discovery_url)])
 
-    def use_placement(self):
+    def use_cinder(self):
         self.__do_register_uris([
-            self.get_placement_discovery_mock_dict()])
+            self.get_cinder_discovery_mock_dict()])
+
+    def use_placement(self, **kwargs):
+        self.__do_register_uris([
+            self.get_placement_discovery_mock_dict(**kwargs)])
 
     def use_designate(self):
         # NOTE(slaweq): This method is only meant to be used in "setUp"
@@ -545,6 +621,15 @@ class TestCase(base.TestCase):
         self.__do_register_uris([
             self.get_senlin_discovery_mock_dict()])
 
+    def use_cyborg(self):
+        # NOTE(s_shogo): This method is only meant to be used in "setUp"
+        # where the ordering of the url being registered is tightly controlled
+        # if the functionality of .use_cyborg is meant to be used during an
+        # actual test case, use .get_cyborg_discovery_mock and apply to the
+        # right location in the mock_uris when calling .register_uris
+        self.__do_register_uris([
+            self.get_cyborg_discovery_mock_dict()])
+
     def register_uris(self, uri_mock_list=None):
         """Mock a list of URIs and responses via requests mock.
 
@@ -607,7 +692,8 @@ class TestCase(base.TestCase):
             if 'content-type' not in headers:
                 headers[u'content-type'] = 'application/json'
 
-            to_mock['headers'] = headers
+            if 'exc' not in to_mock:
+                to_mock['headers'] = headers
 
             self.calls += [
                 dict(
