@@ -17,7 +17,6 @@ from openstack.block_storage.v3 import snapshot
 from openstack.block_storage.v3 import stats
 from openstack.block_storage.v3 import type
 from openstack.block_storage.v3 import volume
-from openstack import exceptions
 from openstack.tests.unit import test_proxy_base
 
 
@@ -75,6 +74,56 @@ class TestVolumeProxy(test_proxy_base.TestProxyBase):
     def test_type_update(self):
         self.verify_update(self.proxy.update_type, type.Type)
 
+    def test_type_extra_specs_update(self):
+        kwargs = {"a": "1", "b": "2"}
+        id = "an_id"
+        self._verify2(
+            "openstack.block_storage.v3.type.Type.set_extra_specs",
+            self.proxy.update_type_extra_specs,
+            method_args=[id],
+            method_kwargs=kwargs,
+            method_result=type.Type.existing(id=id,
+                                             extra_specs=kwargs),
+            expected_args=[self.proxy],
+            expected_kwargs=kwargs,
+            expected_result=kwargs)
+
+    def test_type_extra_specs_delete(self):
+        self._verify2(
+            "openstack.block_storage.v3.type.Type.delete_extra_specs",
+            self.proxy.delete_type_extra_specs,
+            expected_result=None,
+            method_args=["value", "key"],
+            expected_args=[self.proxy, "key"])
+
+    def test_type_encryption_get(self):
+        self.verify_get(self.proxy.get_type_encryption,
+                        type.TypeEncryption,
+                        expected_args=[type.TypeEncryption],
+                        expected_kwargs={
+                            'volume_type_id': 'value',
+                            'requires_id': False
+                        })
+
+    def test_type_encryption_create(self):
+        self.verify_create(self.proxy.create_type_encryption,
+                           type.TypeEncryption,
+                           method_kwargs={'volume_type': 'id'},
+                           expected_kwargs={'volume_type_id': 'id'}
+                           )
+
+    def test_type_encryption_update(self):
+        self.verify_update(self.proxy.update_type_encryption,
+                           type.TypeEncryption)
+
+    def test_type_encryption_delete(self):
+        self.verify_delete(self.proxy.delete_type_encryption,
+                           type.TypeEncryption, False)
+
+    def test_type_encryption_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_type_encryption,
+                           type.TypeEncryption, True)
+
     def test_volume_get(self):
         self.verify_get(self.proxy.get_volume, volume.Volume)
 
@@ -169,16 +218,3 @@ class TestVolumeProxy(test_proxy_base.TestProxyBase):
             expected_args=[self.proxy],
             expected_kwargs={'volume_id': 'vol_id', 'name': 'name'}
         )
-
-    def test_backup_no_swift(self):
-        """Ensure proxy method raises exception if swift is not available
-        """
-        # NOTE: mock has_service
-        self.proxy._connection = mock.Mock()
-        self.proxy._connection.has_service = mock.Mock(return_value=False)
-        self.assertRaises(
-            exceptions.SDKException,
-            self.proxy.restore_backup,
-            'backup',
-            'volume_id',
-            'name')
