@@ -18,6 +18,7 @@ from testscenarios import load_tests_apply_scenarios as load_tests  # noqa
 import openstack
 import openstack.cloud
 from openstack.cloud import meta
+from openstack.compute.v2 import flavor as _flavor
 from openstack import exceptions
 from openstack.tests import fakes
 from openstack.tests.unit import base
@@ -117,7 +118,7 @@ class TestMemoryCache(base.TestCase):
                                         for p in project_list]}
 
         mock_uri = self.get_mock_url(
-            service_type='identity', interface='admin', resource='projects',
+            service_type='identity', resource='projects',
             base_url_append='v3')
 
         self.register_uris([
@@ -206,6 +207,7 @@ class TestMemoryCache(base.TestCase):
                                         'Volume 2 Display Name')
         fake_volume2_dict = meta.obj_to_munch(fake_volume2)
         self.register_uris([
+            self.get_cinder_discovery_mock_dict(),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'volumev2', 'public', append=['volumes', 'detail']),
@@ -236,6 +238,7 @@ class TestMemoryCache(base.TestCase):
                                         'Volume 2 Display Name')
         fake_volume2_dict = meta.obj_to_munch(fake_volume2)
         self.register_uris([
+            self.get_cinder_discovery_mock_dict(),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'volumev2', 'public', append=['volumes', 'detail']),
@@ -266,6 +269,7 @@ class TestMemoryCache(base.TestCase):
             fake_vol_avail['status'] = 'deleting'
 
         self.register_uris([
+            self.get_cinder_discovery_mock_dict(),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'volumev2', 'public', append=['volumes', 'detail']),
@@ -323,7 +327,6 @@ class TestMemoryCache(base.TestCase):
             dict(method='GET',
                  uri=self.get_mock_url(
                      service_type='identity',
-                     interface='admin',
                      resource='users',
                      base_url_append='v3'),
                  status_code=200,
@@ -434,10 +437,16 @@ class TestMemoryCache(base.TestCase):
             endpoint=fakes.COMPUTE_ENDPOINT)
 
         uris_to_mock = [
-            dict(method='GET', uri=mock_uri, json={'flavors': []}),
             dict(method='GET', uri=mock_uri,
+                 validate=dict(
+                     headers={'OpenStack-API-Version': 'compute 2.53'}),
+                 json={'flavors': []}),
+            dict(method='GET', uri=mock_uri,
+                 validate=dict(
+                     headers={'OpenStack-API-Version': 'compute 2.53'}),
                  json={'flavors': fakes.FAKE_FLAVOR_LIST})
         ]
+        self.use_compute_discovery()
 
         self.register_uris(uris_to_mock)
 
@@ -445,8 +454,11 @@ class TestMemoryCache(base.TestCase):
 
         self.assertEqual([], self.cloud.list_flavors())
 
-        fake_flavor_dicts = self.cloud._normalize_flavors(
-            fakes.FAKE_FLAVOR_LIST)
+        fake_flavor_dicts = [
+            _flavor.Flavor(connection=self.cloud, **f)
+            for f in fakes.FAKE_FLAVOR_LIST
+        ]
+
         self.cloud.list_flavors.invalidate(self.cloud)
         self.assertEqual(fake_flavor_dicts, self.cloud.list_flavors())
 
