@@ -51,6 +51,13 @@ class TestFlavor(TestComputeProxy):
     def test_flavor_find(self):
         self.verify_find(self.proxy.find_flavor, flavor.Flavor)
 
+    def test_flavor_find_query(self):
+        self.verify_find(
+            self.proxy.find_flavor, flavor.Flavor,
+            method_kwargs={"a": "b"},
+            expected_kwargs={"a": "b", "ignore_missing": False}
+        )
+
     def test_flavor_find_fetch_extra(self):
         """fetch extra_specs is triggered"""
         with mock.patch(
@@ -133,17 +140,56 @@ class TestFlavor(TestComputeProxy):
             )
             mocked.assert_not_called()
 
-    def test_flavors_detailed(self):
-        self.verify_list(self.proxy.flavors, flavor.FlavorDetail,
-                         method_kwargs={"details": True, "query": 1},
-                         expected_kwargs={"query": 1,
-                                          "base_path": "/flavors/detail"})
+    @mock.patch("openstack.proxy.Proxy._list", auto_spec=True)
+    @mock.patch("openstack.compute.v2.flavor.Flavor.fetch_extra_specs",
+                auto_spec=True)
+    def test_flavors_detailed(self, fetch_mock, list_mock):
+        res = self.proxy.flavors(details=True)
+        for r in res:
+            self.assertIsNotNone(r)
+        fetch_mock.assert_not_called()
+        list_mock.assert_called_with(
+            flavor.Flavor,
+            base_path="/flavors/detail"
+        )
 
-    def test_flavors_not_detailed(self):
-        self.verify_list(self.proxy.flavors, flavor.Flavor,
-                         method_kwargs={"details": False, "query": 1},
-                         expected_kwargs={"query": 1,
-                                          "base_path": "/flavors"})
+    @mock.patch("openstack.proxy.Proxy._list", auto_spec=True)
+    @mock.patch("openstack.compute.v2.flavor.Flavor.fetch_extra_specs",
+                auto_spec=True)
+    def test_flavors_not_detailed(self, fetch_mock, list_mock):
+        res = self.proxy.flavors(details=False)
+        for r in res:
+            self.assertIsNotNone(r)
+        fetch_mock.assert_not_called()
+        list_mock.assert_called_with(
+            flavor.Flavor,
+            base_path="/flavors"
+        )
+
+    @mock.patch("openstack.proxy.Proxy._list", auto_spec=True)
+    @mock.patch("openstack.compute.v2.flavor.Flavor.fetch_extra_specs",
+                auto_spec=True)
+    def test_flavors_query(self, fetch_mock, list_mock):
+        res = self.proxy.flavors(details=False, get_extra_specs=True, a="b")
+        for r in res:
+            fetch_mock.assert_called_with(self.proxy)
+        list_mock.assert_called_with(
+            flavor.Flavor,
+            base_path="/flavors",
+            a="b"
+        )
+
+    @mock.patch("openstack.proxy.Proxy._list", auto_spec=True)
+    @mock.patch("openstack.compute.v2.flavor.Flavor.fetch_extra_specs",
+                auto_spec=True)
+    def test_flavors_get_extra(self, fetch_mock, list_mock):
+        res = self.proxy.flavors(details=False, get_extra_specs=True)
+        for r in res:
+            fetch_mock.assert_called_with(self.proxy)
+        list_mock.assert_called_with(
+            flavor.Flavor,
+            base_path="/flavors"
+        )
 
     def test_flavor_get_access(self):
         self._verify("openstack.compute.v2.flavor.Flavor.get_access",
@@ -306,6 +352,99 @@ class TestAggregate(TestComputeProxy):
             expected_args=[[{'id': '1'}, {'id': '2'}]])
 
 
+class TestService(TestComputeProxy):
+    def test_services(self):
+        self.verify_list_no_kwargs(
+            self.proxy.services, service.Service)
+
+    @mock.patch('openstack.utils.supports_microversion', autospec=True,
+                return_value=False)
+    def test_enable_service_252(self, mv_mock):
+        self._verify2(
+            'openstack.compute.v2.service.Service.enable',
+            self.proxy.enable_service,
+            method_args=["value", "host1", "nova-compute"],
+            expected_args=[self.proxy, "host1", "nova-compute"]
+        )
+
+    @mock.patch('openstack.utils.supports_microversion', autospec=True,
+                return_value=True)
+    def test_enable_service_253(self, mv_mock):
+        self._verify2(
+            'openstack.proxy.Proxy._update',
+            self.proxy.enable_service,
+            method_args=["value"],
+            method_kwargs={},
+            expected_args=[service.Service, "value"],
+            expected_kwargs={'status': 'enabled'}
+        )
+
+    @mock.patch('openstack.utils.supports_microversion', autospec=True,
+                return_value=False)
+    def test_disable_service_252(self, mv_mock):
+        self._verify2(
+            'openstack.compute.v2.service.Service.disable',
+            self.proxy.disable_service,
+            method_args=["value", "host1", "nova-compute"],
+            expected_args=[self.proxy, "host1", "nova-compute", None])
+
+    @mock.patch('openstack.utils.supports_microversion', autospec=True,
+                return_value=True)
+    def test_disable_service_253(self, mv_mock):
+        self._verify2(
+            'openstack.proxy.Proxy._update',
+            self.proxy.disable_service,
+            method_args=["value"],
+            method_kwargs={'disabled_reason': 'some_reason'},
+            expected_args=[service.Service, "value"],
+            expected_kwargs={
+                'status': 'disabled',
+                'disabled_reason': 'some_reason'
+            }
+        )
+
+    @mock.patch('openstack.utils.supports_microversion', autospec=True,
+                return_value=False)
+    def test_force_service_down_252(self, mv_mock):
+        self._verify2(
+            'openstack.compute.v2.service.Service.set_forced_down',
+            self.proxy.update_service_forced_down,
+            method_args=["value", "host1", "nova-compute"],
+            expected_args=[self.proxy, "host1", "nova-compute", True])
+
+    @mock.patch('openstack.utils.supports_microversion', autospec=True,
+                return_value=False)
+    def test_force_service_down_252_empty_vals(self, mv_mock):
+        self.assertRaises(
+            ValueError,
+            self.proxy.update_service_forced_down,
+            "value", None, None
+        )
+
+    @mock.patch('openstack.utils.supports_microversion', autospec=True,
+                return_value=False)
+    def test_force_service_down_252_empty_vals_svc(self, mv_mock):
+        self._verify2(
+            'openstack.compute.v2.service.Service.set_forced_down',
+            self.proxy.update_service_forced_down,
+            method_args=[{'host': 'a', 'binary': 'b'}, None, None],
+            expected_args=[self.proxy, None, None, True])
+
+    def test_find_service(self):
+        self.verify_find(
+            self.proxy.find_service,
+            service.Service,
+        )
+
+    def test_find_service_args(self):
+        self.verify_find(
+            self.proxy.find_service,
+            service.Service,
+            method_kwargs={'host': 'h1'},
+            expected_kwargs={'host': 'h1'}
+        )
+
+
 class TestCompute(TestComputeProxy):
     def test_extension_find(self):
         self.verify_find(self.proxy.find_extension, extension.Extension)
@@ -747,28 +886,6 @@ class TestCompute(TestComputeProxy):
         self.verify_get(self.proxy.get_hypervisor,
                         hypervisor.Hypervisor)
 
-    def test_services(self):
-        self.verify_list_no_kwargs(self.proxy.services,
-                                   service.Service)
-
-    def test_enable_service(self):
-        self._verify('openstack.compute.v2.service.Service.enable',
-                     self.proxy.enable_service,
-                     method_args=["value", "host1", "nova-compute"],
-                     expected_args=["host1", "nova-compute"])
-
-    def test_disable_service(self):
-        self._verify('openstack.compute.v2.service.Service.disable',
-                     self.proxy.disable_service,
-                     method_args=["value", "host1", "nova-compute"],
-                     expected_args=["host1", "nova-compute", None])
-
-    def test_force_service_down(self):
-        self._verify('openstack.compute.v2.service.Service.force_down',
-                     self.proxy.force_service_down,
-                     method_args=["value", "host1", "nova-compute"],
-                     expected_args=["host1", "nova-compute"])
-
     def test_live_migrate_server(self):
         self._verify('openstack.compute.v2.server.Server.live_migrate',
                      self.proxy.live_migrate_server,
