@@ -9,9 +9,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from testscenarios import load_tests_apply_scenarios as load_tests  # noqa
 
-import mock
-import six
+from unittest import mock
 
 from openstack import exceptions
 from openstack.orchestration.v1 import _proxy
@@ -252,7 +252,7 @@ class TestOrchestrationProxy(test_proxy_base.TestProxyBase):
 
         ex = self.assertRaises(exceptions.ResourceNotFound,
                                self.proxy.resources, stack_name)
-        self.assertEqual('No stack found for test_stack', six.text_type(ex))
+        self.assertEqual('No stack found for test_stack', str(ex))
 
     def test_create_software_config(self):
         self.verify_create(self.proxy.create_software_config,
@@ -306,9 +306,47 @@ class TestOrchestrationProxy(test_proxy_base.TestProxyBase):
             ignore_errors=ignore_errors)
         self.assertEqual(mock_validate.return_value, res)
 
+    def test_validate_template_no_env(self):
+        tmpl = "openstack/tests/unit/orchestration/v1/hello_world.yaml"
+
+        res = self.proxy.read_env_and_templates(tmpl)
+
+        self.assertIsInstance(res, dict)
+        self.assertIsInstance(res["files"], dict)
+
     def test_validate_template_invalid_request(self):
         err = self.assertRaises(exceptions.InvalidRequest,
                                 self.proxy.validate_template,
                                 None, template_url=None)
         self.assertEqual("'template_url' must be specified when template is "
-                         "None", six.text_type(err))
+                         "None", str(err))
+
+
+class TestExtractName(TestOrchestrationProxy):
+
+    scenarios = [
+        ('stacks', dict(url='/stacks', parts=['stacks'])),
+        ('name_id', dict(url='/stacks/name/id', parts=['stack'])),
+        ('identity', dict(url='/stacks/id', parts=['stack'])),
+        ('preview', dict(url='/stacks/name/preview',
+                         parts=['stack', 'preview'])),
+        ('stack_act', dict(url='/stacks/name/id/preview',
+                           parts=['stack', 'preview'])),
+        ('stack_subres', dict(url='/stacks/name/id/resources',
+                              parts=['stack', 'resources'])),
+        ('stack_subres_id', dict(url='/stacks/name/id/resources/id',
+                                 parts=['stack', 'resource'])),
+        ('stack_subres_id_act',
+            dict(url='/stacks/name/id/resources/id/action',
+                 parts=['stack', 'resource', 'action'])),
+        ('event',
+         dict(url='/stacks/ignore/ignore/resources/ignore/events/id',
+              parts=['stack', 'resource', 'event'])),
+        ('sd_metadata', dict(url='/software_deployments/metadata/ignore',
+                             parts=['software_deployment', 'metadata']))
+    ]
+
+    def test_extract_name(self):
+
+        results = self.proxy._extract_name(self.url)
+        self.assertEqual(self.parts, results)
