@@ -94,18 +94,23 @@ def get_string_format_keys(fmt_string, old_style=True):
         return keys
 
 
-def supports_microversion(adapter, microversion):
+def supports_microversion(adapter, microversion, raise_exception=False):
     """Determine if the given adapter supports the given microversion.
 
-    Checks the min and max microversion asserted by the service and checks
-    to make sure that ``min <= microversion <= max``.
+    Checks the min and max microversion asserted by the service and checks to
+    make sure that ``min <= microversion <= max``. Current default microversion
+    is taken into consideration if set and verifies that ``microversion <=
+    default``.
 
-    :param adapter:
-        :class:`~keystoneauth1.adapter.Adapter` instance.
-    :param str microversion:
-        String containing the desired microversion.
+    :param adapter: :class:`~keystoneauth1.adapter.Adapter` instance.
+    :param str microversion: String containing the desired microversion.
+    :param bool raise_exception: Raise exception when requested microversion
+        is not supported be the server side or is higher than the current
+        default microversion.
     :returns: True if the service supports the microversion.
     :rtype: bool
+    :raises: :class:`~openstack.exceptions.SDKException` when requested
+        microversion is not supported.
     """
 
     endpoint_data = adapter.get_endpoint_data()
@@ -115,10 +120,41 @@ def supports_microversion(adapter, microversion):
                 endpoint_data.min_microversion,
                 endpoint_data.max_microversion,
                 microversion)):
+        if adapter.default_microversion is not None:
+            # If default_microversion is set - evaluate
+            # whether it match the expectation
+            candidate = discover.normalize_version_number(
+                adapter.default_microversion)
+            required = discover.normalize_version_number(microversion)
+            supports = discover.version_match(required, candidate)
+            if raise_exception and not supports:
+                raise exceptions.SDKException(
+                    'Required microversion {ver} is higher than currently '
+                    'selected {curr}'.format(
+                        ver=microversion,
+                        curr=adapter.default_microversion)
+                )
+            return supports
         return True
+    if raise_exception:
+        raise exceptions.SDKException(
+            'Required microversion {ver} is not supported '
+            'by the server side'.format(ver=microversion)
+        )
     return False
 
 
+def require_microversion(adapter, required):
+    """Require microversion.
+
+    :param adapter: :class:`~keystoneauth1.adapter.Adapter` instance.
+    :param str microversion: String containing the desired microversion.
+    :raises: :class:`~openstack.exceptions.SDKException` when requested
+        microversion is not supported
+    """
+    supports_microversion(adapter, required, raise_exception=True)
+
+
 def pick_microversion(session, required):
     """Get a new microversion if it is higher than session's default.
 
@@ -145,6 +181,10 @@ def pick_microversion(session, required):
                         else required)
 
     if required is not None:
+        if not supports_microversion(session, required):
+            raise exceptions.SDKException(
+                'Requested microversion is not supported by the server side '
+                'or the default microversion is too low')
         return discover.version_to_string(required)
 
 
@@ -297,3 +337,6 @@ class TinyDAG:
 
     def size(self):
         return len(self._graph.keys())
+
+    def is_complete(self):
+        return len(self._done) == self.size()
